==> flutter_flavorizr-2.1.2.tar.gz: lib/processors/commons/runtime_file_string_processor.dart <==
/*
 * Copyright (c) 2022 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'package:flutter_flavorizr/exception/file_not_found_exception.dart';
import 'package:flutter_flavorizr/parser/models/flavorizr.dart';
import 'package:flutter_flavorizr/processors/commons/abstract_file_string_processor.dart';
import 'package:flutter_flavorizr/processors/commons/string_processor.dart';

class RuntimeFileStringProcessor extends AbstractFileStringProcessor {
  RuntimeFileStringProcessor(
    String path,
    StringProcessor processor, {
    required Flavorizr config,
  }) : super(
          path,
          processor,
          config: config,
        );

  @override
  void execute() {
    if (!this.file.existsSync()) {
      throw new FileNotFoundException(path);
    }

    processor.input = this.file.readAsStringSync();

    super.execute();
  }

  @override
  String toString() =>
      "FileProcessor: creating file $path with nested $processor";
}

==> flutter_flavorizr-2.1.3.tar.gz: lib/processors/commons/runtime_file_string_processor.dart <==
/*
 * Copyright (c) 2022 MyLittleSuite
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

import 'package:flutter_flavorizr/exception/file_not_found_exception.dart';
import 'package:flutter_flavorizr/parser/models/flavorizr.dart';
import 'package:flutter_flavorizr/processors/commons/abstract_file_string_processor.dart';
import 'package:flutter_flavorizr/processors/commons/string_processor.dart';

class RuntimeFileStringProcessor extends AbstractFileStringProcessor {
  RuntimeFileStringProcessor(
    String path,
    StringProcessor processor, {
    required Flavorizr config,
  }) : super(
          path,
          processor,
          config: config,
        );

  @override
  void execute() {
    if (!file.existsSync()) {
      throw FileNotFoundException(path);
    }

    processor.input = file.readAsStringSync();

    super.execute();
  }

  @override
  String toString() =>
      "FileProcessor: creating file $path with nested $processor";
}
